send_json_log

Function send_json_log 

pub fn send_json_log(entry: JsonLogEntry)
Sends event to event stream.

Note that this method acquires global lock for brief moment. This means that very hot threads can not use this method concurrently, otherwise they will contend for same lock.